@@ -2,17 +2,18 @@
 # !/usr/bin/env python
 # -*- coding: UTF-8 -*-
 from aishu.datafaker.profession.entity import port
-from aishu.datafaker.profession.entity import ip
+from aishu.public import urlJoin
 import requests
 import time
+import json
 
-class Port(object):
+class Port():
     def __init__(self):
         pass
 
     def httpport(self):
-        url = 'http://{ip}/etl/input'.format(ip=ip.date().getTestHostIP)
-        http_port = port.date().getEtlPortNew
+        url = '/etl/input'
+        http_port = port.date().getEtlPortNew()
         body = {
             "community":[],
             "port":http_port,
@@ -26,14 +27,14 @@ class Port(object):
             "timezone":"Asia/Shanghai",
             "charset":"UTF-8"
         }
-        requests.post(url=url, json= body)
-        time.sleep(1)
-        print(http_port)
+        requests.post(urlJoin.url(url), json.dumps(body))
+        time.sleep(60)
         return http_port
 
     def syslogPort(self):
-        url_syslog = 'http://{ip}/etl/input'.format(ip=ip.date().getTestHostIP)
-        syslog_port = port.date().getEtlPortNew
+        url_syslog = '/etl/input'
+        syslog_port = port.date().getEtlPortNew()
+        print(syslog_port)
         body_syslog = {
             "community":[],
             "port": syslog_port,
@@ -46,8 +47,6 @@ class Port(object):
             "type":"syslog",
             "charset":"UTF-8"
         }
-        requests.post(url=url_syslog, json= body_syslog)
+        requests.post(urlJoin.url(url_syslog), json.dumps(body_syslog))
         time.sleep(60)
-        print(syslog_port)
         return syslog_port
-
